==> cxf-testutils-2.0.6.11-fuse-sources.jar: org/apache/type_test/xml/TestUnionWithStringListRestriction.java <==

package org.apache.type_test.xml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlList;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for testUnionWithStringListRestriction element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testUnionWithStringListRestriction">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}UnionWithStringListRestriction"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}UnionWithStringListRestriction"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testUnionWithStringListRestriction")
public class TestUnionWithStringListRestriction {

    @XmlList
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected List<String> x;
    @XmlList
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected List<String> y;

    /**
     * Gets the value of the x property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the x property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getX().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getX() {
        if (x == null) {
            x = new ArrayList<String>();
        }
        return this.x;
    }

    /**
     * Gets the value of the y property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the y property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getY().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getY() {
        if (y == null) {
            y = new ArrayList<String>();
        }
        return this.y;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/xml/TestUnionWithStringListRestriction.java <==

package org.apache.type_test.xml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlList;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}UnionWithStringListRestriction"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}UnionWithStringListRestriction"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testUnionWithStringListRestriction")
public class TestUnionWithStringListRestriction {

    @XmlList
    @XmlElement(required = true)
    protected List<String> x;
    @XmlList
    @XmlElement(required = true)
    protected List<String> y;

    /**
     * Gets the value of the x property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the x property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getX().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getX() {
        if (x == null) {
            x = new ArrayList<String>();
        }
        return this.x;
    }

    /**
     * Gets the value of the y property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the y property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getY().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getY() {
        if (y == null) {
            y = new ArrayList<String>();
        }
        return this.y;
    }

}
